#!/usr/bin/env python
import argparse

from ethminer_supervisor.util import check, restart


parser = argparse.ArgumentParser(description='Process some integers.')
parser.add_argument('--restart', '-R', action='store_true')


def main():
    args = parser.parse_args()
    has_recent = check()
    if args.restart and not has_recent:
        restart()



# -*- coding: utf-8 -*-
from datetime import datetime
from time import sleep
import logging
import subprocess


SERVICE_CMD = ['service', 'ethminer', 'status']
SERVICE_STOP = ['service', 'ethminer', 'stop']
SERVICE_START = ['service', 'ethminer', 'start']
logger = logging.getLogger(__name__)


def check():
    has_recent = False
    for line in get_ethminer_service_output():
        time = parse_time(line)
        if time:
            if is_old_time(time):
                logger.debug('Found old time {}'.format(time))
            else:
                logger.debug('Found recent time {}'.format(time))
                has_recent = True
    if not has_recent:
        logger.info("No recent times found for ethminer!")
    else:
        logger.info("Ethminer recent status time found :)")
    return has_recent


def restart():
    logger.info('Restarting ethminer...')
    subprocess.Popen(SERVICE_STOP)
    sleep(1)
    subprocess.Popen(SERVICE_START)
    logger.info('Ethminer restarted')


def get_ethminer_service_output():
    proc = subprocess.Popen(SERVICE_CMD, stdout=subprocess.PIPE)
    while True:
        line = proc.stdout.readline()
        if line:
            yield line
        else:
            break


def parse_time(line):
    line_segments = line.split(' ')
    if len(line_segments) > 3:
        try:
            line_date = ' '.join(line_segments[:3])
            return datetime.strptime(line_date, "%b %d %H:%M:%S")
        except ValueError:
            logger.debug('Line doesnt have a valid time, skipping')
    return None


def is_old_time(time, delta_seconds=60*4):
    return (datetime.now() - time).total_seconds() > delta_seconds



#!/usr/bin/env python
# -*- coding: utf-8 -*-


from datetime import datetime
import sys
import unittest
try:
    from unittest import patch
except ImportError:
    from mock import patch

from ethminer_supervisor import cli, util


EXAMPLE = ('Dec 1 22:33:44 miner1 ethminer[1]:   m  11:11:11|ethminer  '
           'Speed 1.00 Mh/s    gpu/0 0.50  gpu/1 0.50 [A44+0:R0+0:F0] Time: 00:01')


class TestSupervisor(unittest.TestCase):
    def test_parse_time(self):
        time = util.parse_time(EXAMPLE)
        self.assertEquals(1, time.day)
        self.assertEquals(22, time.hour)
        self.assertEquals(33, time.minute)

    def test_old_time(self):
        response = util.is_old_time(datetime(year=2017, month=12, day=1, second=1))
        self.assertEquals(True, response)

    def test_cli(self):
        testargs = ["ethminer_supervisor"]
        with patch.object(sys, 'argv', testargs):
            cli.main()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

requirements = [
]

test_requirements = [
    'coverage',
    'flake8',
    'mock',
    'tox',
]

setup(
    name='ethminer_supervisor',
    version='1.0.0',
    description="Supervise ethminer daemon and restart process or machine when appropriate",
    long_description=readme,
    author="Jon Robison",
    author_email='narfman0@gmail.com',
    url='https://github.com/narfman0/ethminer_supervisor',
    packages=find_packages(),
    include_package_data=True,
    install_requires=requirements,
    license="MIT license",
    zip_safe=True,
    keywords='ethminer_supervisor ethereum',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        "Programming Language :: Python :: 2",
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
    ],
    test_suite='tests',
    tests_require=test_requirements,
    entry_points={
        'console_scripts': ['ethminer_supervisor=ethminer_supervisor.cli:main'],
    }
)
